# SwaggerClient-php
Daily and hourly UV data for latitude/longitude points, ZIP/Postal Codes, and Designated Market Areas. UV forecast is up to 5 days out from the current day. Historical UV data is also available. The Weather Source UV API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

This PHP package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Build package: io.swagger.codegen.v3.generators.php.PhpClientCodegen
For more information, please visit [https://developer.weathersourceapis.com/](https://developer.weathersourceapis.com/)

## Requirements

PHP 5.5 and later

## Installation & Usage
### Composer

To install the bindings via [Composer](http://getcomposer.org/), add the following to `composer.json`:

```
{
  "repositories": [
    {
      "type": "git",
      "url": "https://github.com/GIT_USER_ID/GIT_REPO_ID.git"
    }
  ],
  "require": {
    "GIT_USER_ID/GIT_REPO_ID": "*@dev"
  }
}
```

Then run `composer install`

### Manual Installation

Download the files and include `autoload.php`:

```php
    require_once('/path/to/SwaggerClient-php/vendor/autoload.php');
```

## Tests

To run the unit tests:

```
composer install
./vendor/bin/phpunit
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$date = new \DateTime("2013-10-20"); // \DateTime | An date formatted as a RFC3339 date value.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdDaysDateGet($dma_id, $date, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdDaysDateGet: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$date_start = new \DateTime("2013-10-20"); // \DateTime | An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
$date_end = new \DateTime("2013-10-20"); // \DateTime | An date formatted as a RFC3339 date value that must occur temporally after dateStart.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdDaysDateStartdateEndGet($dma_id, $date_start, $date_end, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdDaysDateStartdateEndGet: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdDaysGet($dma_id, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdDaysGet: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdHoursGet($dma_id, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdHoursGet: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$timestamp = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdHoursTimestampGet($dma_id, $timestamp, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdHoursTimestampGet: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$timestamp_start = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
$timestamp_end = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdHoursTimestampStarttimestampEndGet($dma_id, $timestamp_start, $timestamp_end, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdHoursTimestampStarttimestampEndGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

## Documentation for API Endpoints

All URIs are relative to *https://uv.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DmasApi* | [**dmasDmaIdDaysDateGet**](docs/Api/DmasApi.md#dmasdmaiddaysdateget) | **GET** /dmas/{dmaId}/days/{date} | A day of UV data for a DMA.
*DmasApi* | [**dmasDmaIdDaysDateStartdateEndGet**](docs/Api/DmasApi.md#dmasdmaiddaysdatestartdateendget) | **GET** /dmas/{dmaId}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for a DMA.
*DmasApi* | [**dmasDmaIdDaysGet**](docs/Api/DmasApi.md#dmasdmaiddaysget) | **GET** /dmas/{dmaId}/days | The complete daily UV forecast for a DMA.
*DmasApi* | [**dmasDmaIdHoursGet**](docs/Api/DmasApi.md#dmasdmaidhoursget) | **GET** /dmas/{dmaId}/hours | The complete hourly UV forecast for a DMA
*DmasApi* | [**dmasDmaIdHoursTimestampGet**](docs/Api/DmasApi.md#dmasdmaidhourstimestampget) | **GET** /dmas/{dmaId}/hours/{timestamp} | An hour of UV data for a DMA
*DmasApi* | [**dmasDmaIdHoursTimestampStarttimestampEndGet**](docs/Api/DmasApi.md#dmasdmaidhourstimestampstarttimestampendget) | **GET** /dmas/{dmaId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for a DMA.
*OnpointsApi* | [**onpointsOnpointIdDaysDateGet**](docs/Api/OnpointsApi.md#onpointsonpointiddaysdateget) | **GET** /onpoints/{onpointId}/days/{date} | A day of UV data for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdDaysDateStartdateEndGet**](docs/Api/OnpointsApi.md#onpointsonpointiddaysdatestartdateendget) | **GET** /onpoints/{onpointId}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdDaysGet**](docs/Api/OnpointsApi.md#onpointsonpointiddaysget) | **GET** /onpoints/{onpointId}/days | The complete daily UV forecast for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdHoursGet**](docs/Api/OnpointsApi.md#onpointsonpointidhoursget) | **GET** /onpoints/{onpointId}/hours | The complete hourly UV forecast for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdHoursTimestampGet**](docs/Api/OnpointsApi.md#onpointsonpointidhourstimestampget) | **GET** /onpoints/{onpointId}/hours/{timestamp} | An hour of UV data for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdHoursTimestampStarttimestampEndGet**](docs/Api/OnpointsApi.md#onpointsonpointidhourstimestampstarttimestampendget) | **GET** /onpoints/{onpointId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for an OnPoint™ point.
*PointsApi* | [**pointsLatitudelongitudeDaysDateGet**](docs/Api/PointsApi.md#pointslatitudelongitudedaysdateget) | **GET** /points/{latitude},{longitude}/days/{date} | A day of UV data for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeDaysDateStartdateEndGet**](docs/Api/PointsApi.md#pointslatitudelongitudedaysdatestartdateendget) | **GET** /points/{latitude},{longitude}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeDaysGet**](docs/Api/PointsApi.md#pointslatitudelongitudedaysget) | **GET** /points/{latitude},{longitude}/days | The complete daily UV forecast for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHoursGet**](docs/Api/PointsApi.md#pointslatitudelongitudehoursget) | **GET** /points/{latitude},{longitude}/hours | The complete hourly UV forecast for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHoursTimestampGet**](docs/Api/PointsApi.md#pointslatitudelongitudehourstimestampget) | **GET** /points/{latitude},{longitude}/hours/{timestamp} | An hour of UV data for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHoursTimestampStarttimestampEndGet**](docs/Api/PointsApi.md#pointslatitudelongitudehourstimestampstarttimestampendget) | **GET** /points/{latitude},{longitude}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for a Latitude/Longitude point.
*PostcodesApi* | [**postcodesPostcodecountryCodeDaysDateGet**](docs/Api/PostcodesApi.md#postcodespostcodecountrycodedaysdateget) | **GET** /postcodes/{postcode},{countryCode}/days/{date} | A day of UV data for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeDaysDateStartdateEndGet**](docs/Api/PostcodesApi.md#postcodespostcodecountrycodedaysdatestartdateendget) | **GET** /postcodes/{postcode},{countryCode}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeDaysGet**](docs/Api/PostcodesApi.md#postcodespostcodecountrycodedaysget) | **GET** /postcodes/{postcode},{countryCode}/days | The complete daily UV forecast for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeHoursGet**](docs/Api/PostcodesApi.md#postcodespostcodecountrycodehoursget) | **GET** /postcodes/{postcode},{countryCode}/hours | The complete hourly UV forecast for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeHoursTimestampGet**](docs/Api/PostcodesApi.md#postcodespostcodecountrycodehourstimestampget) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestamp} | An hour of UV data for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet**](docs/Api/PostcodesApi.md#postcodespostcodecountrycodehourstimestampstarttimestampendget) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for a postcode.

## Documentation For Models

 - [BoundingPoints](docs/Model/BoundingPoints.md)
 - [BoundingPointsInner](docs/Model/BoundingPointsInner.md)
 - [CountryCode](docs/Model/CountryCode.md)
 - [CountryName](docs/Model/CountryName.md)
 - [Date](docs/Model/Date.md)
 - [DateEnd](docs/Model/DateEnd.md)
 - [DateRangeObj](docs/Model/DateRangeObj.md)
 - [DateStart](docs/Model/DateStart.md)
 - [Distance](docs/Model/Distance.md)
 - [DistancePop](docs/Model/DistancePop.md)
 - [DmaId](docs/Model/DmaId.md)
 - [DmaName](docs/Model/DmaName.md)
 - [DmaObj](docs/Model/DmaObj.md)
 - [Elevation](docs/Model/Elevation.md)
 - [ErrorObj](docs/Model/ErrorObj.md)
 - [FieldListDayObj](docs/Model/FieldListDayObj.md)
 - [FieldListHourObj](docs/Model/FieldListHourObj.md)
 - [Fields](docs/Model/Fields.md)
 - [Grid](docs/Model/Grid.md)
 - [Latitude](docs/Model/Latitude.md)
 - [Longitude](docs/Model/Longitude.md)
 - [OnpointId](docs/Model/OnpointId.md)
 - [OnpointObj](docs/Model/OnpointObj.md)
 - [PointObj](docs/Model/PointObj.md)
 - [Population](docs/Model/Population.md)
 - [Postcode](docs/Model/Postcode.md)
 - [PostcodeObj](docs/Model/PostcodeObj.md)
 - [SamplePoints](docs/Model/SamplePoints.md)
 - [SamplePointsInner](docs/Model/SamplePointsInner.md)
 - [SubdivCode](docs/Model/SubdivCode.md)
 - [SubdivName](docs/Model/SubdivName.md)
 - [Timestamp](docs/Model/Timestamp.md)
 - [TimestampEnd](docs/Model/TimestampEnd.md)
 - [TimestampInit](docs/Model/TimestampInit.md)
 - [TimestampRangeObj](docs/Model/TimestampRangeObj.md)
 - [TimestampStart](docs/Model/TimestampStart.md)
 - [Timezone](docs/Model/Timezone.md)
 - [UvDayArr](docs/Model/UvDayArr.md)
 - [UvDayObj](docs/Model/UvDayObj.md)
 - [UvDmaDayObj](docs/Model/UvDmaDayObj.md)
 - [UvDmaHourObj](docs/Model/UvDmaHourObj.md)
 - [UvHourArr](docs/Model/UvHourArr.md)
 - [UvHourObj](docs/Model/UvHourObj.md)
 - [UvIndex](docs/Model/UvIndex.md)
 - [UvIndexMax](docs/Model/UvIndexMax.md)
 - [UvOnpointDayObj](docs/Model/UvOnpointDayObj.md)
 - [UvOnpointHourObj](docs/Model/UvOnpointHourObj.md)
 - [UvPointDayObj](docs/Model/UvPointDayObj.md)
 - [UvPointHourObj](docs/Model/UvPointHourObj.md)
 - [UvPostcodeDayObj](docs/Model/UvPostcodeDayObj.md)
 - [UvPostcodeHourObj](docs/Model/UvPostcodeHourObj.md)

## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

support@weathersource.com

