# Swagger\Client\DmasApi

All URIs are relative to *https://uv.weathersourceapis.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**dmasDmaIdDaysDateGet**](DmasApi.md#dmasdmaiddaysdateget) | **GET** /dmas/{dmaId}/days/{date} | A day of UV data for a DMA.
[**dmasDmaIdDaysDateStartdateEndGet**](DmasApi.md#dmasdmaiddaysdatestartdateendget) | **GET** /dmas/{dmaId}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for a DMA.
[**dmasDmaIdDaysGet**](DmasApi.md#dmasdmaiddaysget) | **GET** /dmas/{dmaId}/days | The complete daily UV forecast for a DMA.
[**dmasDmaIdHoursGet**](DmasApi.md#dmasdmaidhoursget) | **GET** /dmas/{dmaId}/hours | The complete hourly UV forecast for a DMA
[**dmasDmaIdHoursTimestampGet**](DmasApi.md#dmasdmaidhourstimestampget) | **GET** /dmas/{dmaId}/hours/{timestamp} | An hour of UV data for a DMA
[**dmasDmaIdHoursTimestampStarttimestampEndGet**](DmasApi.md#dmasdmaidhourstimestampstarttimestampendget) | **GET** /dmas/{dmaId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for a DMA.

# **dmasDmaIdDaysDateGet**
> \Swagger\Client\Model\UvDmaDayObj dmasDmaIdDaysDateGet($dma_id, $date, $fields, $unit_scale)

A day of UV data for a DMA.

Returns a single day of UV data for a Designated Market Area. The provided date must exist within the current valid 5-day forecast range, or it must be a historical date.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');
// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$date = new \DateTime("2013-10-20"); // \DateTime | An date formatted as a RFC3339 date value.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdDaysDateGet($dma_id, $date, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdDaysDateGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dma_id** | **int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). |
 **date** | **\DateTime**| An date formatted as a RFC3339 date value. |
 **fields** | [**string[]**](../Model/string.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* |
 **unit_scale** | **string**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**\Swagger\Client\Model\UvDmaDayObj**](../Model/UvDmaDayObj.md)

### Authorization

[ApiKeyAuth](../../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **dmasDmaIdDaysDateStartdateEndGet**
> \Swagger\Client\Model\UvDmaDayObj dmasDmaIdDaysDateStartdateEndGet($dma_id, $date_start, $date_end, $fields, $unit_scale)

A contiguous range of daily UV data for a DMA.

Returns a contiguous range of daily UV data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');
// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$date_start = new \DateTime("2013-10-20"); // \DateTime | An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
$date_end = new \DateTime("2013-10-20"); // \DateTime | An date formatted as a RFC3339 date value that must occur temporally after dateStart.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdDaysDateStartdateEndGet($dma_id, $date_start, $date_end, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdDaysDateStartdateEndGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dma_id** | **int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). |
 **date_start** | **\DateTime**| An date formatted as a RFC3339 date value that must occur temporally before dateEnd. |
 **date_end** | **\DateTime**| An date formatted as a RFC3339 date value that must occur temporally after dateStart. |
 **fields** | [**string[]**](../Model/string.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* |
 **unit_scale** | **string**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**\Swagger\Client\Model\UvDmaDayObj**](../Model/UvDmaDayObj.md)

### Authorization

[ApiKeyAuth](../../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **dmasDmaIdDaysGet**
> \Swagger\Client\Model\UvDmaDayObj dmasDmaIdDaysGet($dma_id, $fields, $unit_scale)

The complete daily UV forecast for a DMA.

Returns the complete set of UV forecast data for a Designated Market Area.  *Alternatively using a query that specificies just the days required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');
// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdDaysGet($dma_id, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdDaysGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dma_id** | **int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). |
 **fields** | [**string[]**](../Model/string.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* |
 **unit_scale** | **string**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**\Swagger\Client\Model\UvDmaDayObj**](../Model/UvDmaDayObj.md)

### Authorization

[ApiKeyAuth](../../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **dmasDmaIdHoursGet**
> \Swagger\Client\Model\UvDmaHourObj dmasDmaIdHoursGet($dma_id, $fields, $unit_scale)

The complete hourly UV forecast for a DMA

Returns the complete set of UV forecast data for a Designated Market Area.  *Alternatively using a query that specificies just the hours required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');
// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdHoursGet($dma_id, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdHoursGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dma_id** | **int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). |
 **fields** | [**string[]**](../Model/string.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* |
 **unit_scale** | **string**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**\Swagger\Client\Model\UvDmaHourObj**](../Model/UvDmaHourObj.md)

### Authorization

[ApiKeyAuth](../../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **dmasDmaIdHoursTimestampGet**
> \Swagger\Client\Model\UvDmaHourObj dmasDmaIdHoursTimestampGet($dma_id, $timestamp, $fields, $unit_scale)

An hour of UV data for a DMA

Returns a single hour of UV data for a Designated Market Area. The provided timestamp must exist within the current valid 5-day forecast range, or it must be a historical timestamp.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');
// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$timestamp = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdHoursTimestampGet($dma_id, $timestamp, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdHoursTimestampGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dma_id** | **int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). |
 **timestamp** | **\DateTime**| A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. |
 **fields** | [**string[]**](../Model/string.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* |
 **unit_scale** | **string**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**\Swagger\Client\Model\UvDmaHourObj**](../Model/UvDmaHourObj.md)

### Authorization

[ApiKeyAuth](../../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **dmasDmaIdHoursTimestampStarttimestampEndGet**
> \Swagger\Client\Model\UvDmaHourObj dmasDmaIdHoursTimestampStarttimestampEndGet($dma_id, $timestamp_start, $timestamp_end, $fields, $unit_scale)

A contiguous range of hourly UV data for a DMA.

Returns a contiguous range of hourly UV data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');
// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$timestamp_start = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
$timestamp_end = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdHoursTimestampStarttimestampEndGet($dma_id, $timestamp_start, $timestamp_end, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdHoursTimestampStarttimestampEndGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **dma_id** | **int**| A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/). |
 **timestamp_start** | **\DateTime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. |
 **timestamp_end** | **\DateTime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. |
 **fields** | [**string[]**](../Model/string.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* |
 **unit_scale** | **string**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**\Swagger\Client\Model\UvDmaHourObj**](../Model/UvDmaHourObj.md)

### Authorization

[ApiKeyAuth](../../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

