# Swagger\Client\PostcodesApi

All URIs are relative to *https://uv.weathersourceapis.com/v2*

Method | HTTP request | Description
------------- | ------------- | -------------
[**postcodesPostcodecountryCodeDaysDateGet**](PostcodesApi.md#postcodespostcodecountrycodedaysdateget) | **GET** /postcodes/{postcode},{countryCode}/days/{date} | A day of UV data for a postcode.
[**postcodesPostcodecountryCodeDaysDateStartdateEndGet**](PostcodesApi.md#postcodespostcodecountrycodedaysdatestartdateendget) | **GET** /postcodes/{postcode},{countryCode}/days/{dateStart},{dateEnd} | A contiguous range of daily UV data for a postcode.
[**postcodesPostcodecountryCodeDaysGet**](PostcodesApi.md#postcodespostcodecountrycodedaysget) | **GET** /postcodes/{postcode},{countryCode}/days | The complete daily UV forecast for a postcode.
[**postcodesPostcodecountryCodeHoursGet**](PostcodesApi.md#postcodespostcodecountrycodehoursget) | **GET** /postcodes/{postcode},{countryCode}/hours | The complete hourly UV forecast for a postcode.
[**postcodesPostcodecountryCodeHoursTimestampGet**](PostcodesApi.md#postcodespostcodecountrycodehourstimestampget) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestamp} | An hour of UV data for a postcode.
[**postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet**](PostcodesApi.md#postcodespostcodecountrycodehourstimestampstarttimestampendget) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly UV data for a postcode.

# **postcodesPostcodecountryCodeDaysDateGet**
> \Swagger\Client\Model\UvPostcodeDayObj postcodesPostcodecountryCodeDaysDateGet($postcode, $country_code, $date, $fields, $unit_scale)

A day of UV data for a postcode.

Returns a single day of UV data for a postcode. The provided date must exist within the current valid 5-day forecast range, or it must be a historical date.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');
// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\PostcodesApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$postcode = "postcode_example"; // string | A postcode string.
$country_code = "country_code_example"; // string | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
$date = new \DateTime("2013-10-20"); // \DateTime | An date formatted as a RFC3339 date value.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->postcodesPostcodecountryCodeDaysDateGet($postcode, $country_code, $date, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling PostcodesApi->postcodesPostcodecountryCodeDaysDateGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **string**| A postcode string. |
 **country_code** | **string**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **date** | **\DateTime**| An date formatted as a RFC3339 date value. |
 **fields** | [**string[]**](../Model/string.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* |
 **unit_scale** | **string**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**\Swagger\Client\Model\UvPostcodeDayObj**](../Model/UvPostcodeDayObj.md)

### Authorization

[ApiKeyAuth](../../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **postcodesPostcodecountryCodeDaysDateStartdateEndGet**
> \Swagger\Client\Model\UvPostcodeDayObj postcodesPostcodecountryCodeDaysDateStartdateEndGet($postcode, $country_code, $date_start, $date_end, $fields, $unit_scale)

A contiguous range of daily UV data for a postcode.

Returns a contiguous range of daily ECMWF forecast data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');
// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\PostcodesApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$postcode = "postcode_example"; // string | A postcode string.
$country_code = "country_code_example"; // string | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
$date_start = new \DateTime("2013-10-20"); // \DateTime | An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
$date_end = new \DateTime("2013-10-20"); // \DateTime | An date formatted as a RFC3339 date value that must occur temporally after dateStart.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->postcodesPostcodecountryCodeDaysDateStartdateEndGet($postcode, $country_code, $date_start, $date_end, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling PostcodesApi->postcodesPostcodecountryCodeDaysDateStartdateEndGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **string**| A postcode string. |
 **country_code** | **string**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **date_start** | **\DateTime**| An date formatted as a RFC3339 date value that must occur temporally before dateEnd. |
 **date_end** | **\DateTime**| An date formatted as a RFC3339 date value that must occur temporally after dateStart. |
 **fields** | [**string[]**](../Model/string.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* |
 **unit_scale** | **string**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**\Swagger\Client\Model\UvPostcodeDayObj**](../Model/UvPostcodeDayObj.md)

### Authorization

[ApiKeyAuth](../../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **postcodesPostcodecountryCodeDaysGet**
> \Swagger\Client\Model\UvPostcodeDayObj postcodesPostcodecountryCodeDaysGet($postcode, $country_code, $fields, $unit_scale)

The complete daily UV forecast for a postcode.

Returns the complete set of UV forecast data for a postcode.  *Alternatively using a query that specificies just the days required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');
// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\PostcodesApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$postcode = "postcode_example"; // string | A postcode string.
$country_code = "country_code_example"; // string | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->postcodesPostcodecountryCodeDaysGet($postcode, $country_code, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling PostcodesApi->postcodesPostcodecountryCodeDaysGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **string**| A postcode string. |
 **country_code** | **string**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **fields** | [**string[]**](../Model/string.md)| A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* |
 **unit_scale** | **string**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**\Swagger\Client\Model\UvPostcodeDayObj**](../Model/UvPostcodeDayObj.md)

### Authorization

[ApiKeyAuth](../../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **postcodesPostcodecountryCodeHoursGet**
> \Swagger\Client\Model\UvPostcodeHourObj postcodesPostcodecountryCodeHoursGet($postcode, $country_code, $fields, $unit_scale)

The complete hourly UV forecast for a postcode.

Returns the complete set of UV forecast data for a postcode.  *Alternatively using a query that specificies just the hours required for your purposes will improve the query response time.*  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');
// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\PostcodesApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$postcode = "postcode_example"; // string | A postcode string.
$country_code = "country_code_example"; // string | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->postcodesPostcodecountryCodeHoursGet($postcode, $country_code, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling PostcodesApi->postcodesPostcodecountryCodeHoursGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **string**| A postcode string. |
 **country_code** | **string**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **fields** | [**string[]**](../Model/string.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* |
 **unit_scale** | **string**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**\Swagger\Client\Model\UvPostcodeHourObj**](../Model/UvPostcodeHourObj.md)

### Authorization

[ApiKeyAuth](../../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **postcodesPostcodecountryCodeHoursTimestampGet**
> \Swagger\Client\Model\UvPostcodeHourObj postcodesPostcodecountryCodeHoursTimestampGet($postcode, $country_code, $timestamp, $fields, $unit_scale)

An hour of UV data for a postcode.

Returns a single hour of ECMWF forecast data for a postcode. The provided timestamp must exist within the current valid 5-day forecast range, or it must be a historical timestamp.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');
// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\PostcodesApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$postcode = "postcode_example"; // string | A postcode string.
$country_code = "country_code_example"; // string | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
$timestamp = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->postcodesPostcodecountryCodeHoursTimestampGet($postcode, $country_code, $timestamp, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling PostcodesApi->postcodesPostcodecountryCodeHoursTimestampGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **string**| A postcode string. |
 **country_code** | **string**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **timestamp** | **\DateTime**| A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. |
 **fields** | [**string[]**](../Model/string.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* |
 **unit_scale** | **string**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**\Swagger\Client\Model\UvPostcodeHourObj**](../Model/UvPostcodeHourObj.md)

### Authorization

[ApiKeyAuth](../../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet**
> \Swagger\Client\Model\UvPostcodeHourObj postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet($postcode, $country_code, $timestamp_start, $timestamp_end, $fields, $unit_scale)

A contiguous range of hourly UV data for a postcode.

Returns a contiguous range of hourly UV data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');
// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\PostcodesApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$postcode = "postcode_example"; // string | A postcode string.
$country_code = "country_code_example"; // string | An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
$timestamp_start = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
$timestamp_end = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet($postcode, $country_code, $timestamp_start, $timestamp_end, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling PostcodesApi->postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **postcode** | **string**| A postcode string. |
 **country_code** | **string**| An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/). |
 **timestamp_start** | **\DateTime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. |
 **timestamp_end** | **\DateTime**| A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. |
 **fields** | [**string[]**](../Model/string.md)| A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* |
 **unit_scale** | **string**| The unit scale for returned values.&lt;br&gt; | [optional] [default to IMPERIAL]

### Return type

[**\Swagger\Client\Model\UvPostcodeHourObj**](../Model/UvPostcodeHourObj.md)

### Authorization

[ApiKeyAuth](../../README.md#ApiKeyAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

