<?php
/**
 * PointsApi
 * PHP version 5
 *
 * @category Class
 * @package  Swagger\Client
 * @author   Swagger Codegen team
 * @link     https://github.com/swagger-api/swagger-codegen
 */

/**
 * UV - A Weather Source API
 *
 * Daily and hourly UV data for latitude/longitude points, ZIP/Postal Codes, and Designated Market Areas. UV forecast is up to 5 days out from the current day. Historical UV data is also available. The Weather Source UV API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  **IMPORTANT:** To authenticate to the Weather Source UV API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page.
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 * Swagger Codegen version: 3.0.27
 */
/**
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen
 * Do not edit the class manually.
 */

namespace Swagger\Client\Api;

use GuzzleHttp\Client;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\RequestException;
use GuzzleHttp\Psr7\MultipartStream;
use GuzzleHttp\Psr7\Request;
use GuzzleHttp\RequestOptions;
use Swagger\Client\ApiException;
use Swagger\Client\Configuration;
use Swagger\Client\HeaderSelector;
use Swagger\Client\ObjectSerializer;

/**
 * PointsApi Class Doc Comment
 *
 * @category Class
 * @package  Swagger\Client
 * @author   Swagger Codegen team
 * @link     https://github.com/swagger-api/swagger-codegen
 */
class PointsApi
{
    /**
     * @var ClientInterface
     */
    protected $client;

    /**
     * @var Configuration
     */
    protected $config;

    /**
     * @var HeaderSelector
     */
    protected $headerSelector;

    /**
     * @param ClientInterface $client
     * @param Configuration   $config
     * @param HeaderSelector  $selector
     */
    public function __construct(
        ClientInterface $client = null,
        Configuration $config = null,
        HeaderSelector $selector = null
    ) {
        $this->client = $client ?: new Client();
        $this->config = $config ?: new Configuration();
        $this->headerSelector = $selector ?: new HeaderSelector();
    }

    /**
     * @return Configuration
     */
    public function getConfig()
    {
        return $this->config;
    }

    /**
     * Operation pointsLatitudelongitudeDaysDateGet
     *
     * A day of UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $date An date formatted as a RFC3339 date value. (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \Swagger\Client\ApiException on non-2xx response
     * @throws \InvalidArgumentException
     * @return \Swagger\Client\Model\UvPointDayObj
     */
    public function pointsLatitudelongitudeDaysDateGet($latitude, $longitude, $date, $fields, $unit_scale = 'IMPERIAL')
    {
        list($response) = $this->pointsLatitudelongitudeDaysDateGetWithHttpInfo($latitude, $longitude, $date, $fields, $unit_scale);
        return $response;
    }

    /**
     * Operation pointsLatitudelongitudeDaysDateGetWithHttpInfo
     *
     * A day of UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $date An date formatted as a RFC3339 date value. (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \Swagger\Client\ApiException on non-2xx response
     * @throws \InvalidArgumentException
     * @return array of \Swagger\Client\Model\UvPointDayObj, HTTP status code, HTTP response headers (array of strings)
     */
    public function pointsLatitudelongitudeDaysDateGetWithHttpInfo($latitude, $longitude, $date, $fields, $unit_scale = 'IMPERIAL')
    {
        $returnType = '\Swagger\Client\Model\UvPointDayObj';
        $request = $this->pointsLatitudelongitudeDaysDateGetRequest($latitude, $longitude, $date, $fields, $unit_scale);

        try {
            $options = $this->createHttpClientOption();
            try {
                $response = $this->client->send($request, $options);
            } catch (RequestException $e) {
                throw new ApiException(
                    "[{$e->getCode()}] {$e->getMessage()}",
                    $e->getCode(),
                    $e->getResponse() ? $e->getResponse()->getHeaders() : null,
                    $e->getResponse() ? $e->getResponse()->getBody()->getContents() : null
                );
            }

            $statusCode = $response->getStatusCode();

            if ($statusCode < 200 || $statusCode > 299) {
                throw new ApiException(
                    sprintf(
                        '[%d] Error connecting to the API (%s)',
                        $statusCode,
                        $request->getUri()
                    ),
                    $statusCode,
                    $response->getHeaders(),
                    $response->getBody()
                );
            }

            $responseBody = $response->getBody();
            if ($returnType === '\SplFileObject') {
                $content = $responseBody; //stream goes to serializer
            } else {
                $content = $responseBody->getContents();
                if (!in_array($returnType, ['string','integer','bool'])) {
                    $content = json_decode($content);
                }
            }

            return [
                ObjectSerializer::deserialize($content, $returnType, []),
                $response->getStatusCode(),
                $response->getHeaders()
            ];

        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = ObjectSerializer::deserialize(
                        $e->getResponseBody(),
                        '\Swagger\Client\Model\UvPointDayObj',
                        $e->getResponseHeaders()
                    );
                    $e->setResponseObject($data);
                    break;
                case 0:
                    $data = ObjectSerializer::deserialize(
                        $e->getResponseBody(),
                        '\Swagger\Client\Model\ErrorObj',
                        $e->getResponseHeaders()
                    );
                    $e->setResponseObject($data);
                    break;
            }
            throw $e;
        }
    }

    /**
     * Operation pointsLatitudelongitudeDaysDateGetAsync
     *
     * A day of UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $date An date formatted as a RFC3339 date value. (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function pointsLatitudelongitudeDaysDateGetAsync($latitude, $longitude, $date, $fields, $unit_scale = 'IMPERIAL')
    {
        return $this->pointsLatitudelongitudeDaysDateGetAsyncWithHttpInfo($latitude, $longitude, $date, $fields, $unit_scale)
            ->then(
                function ($response) {
                    return $response[0];
                }
            );
    }

    /**
     * Operation pointsLatitudelongitudeDaysDateGetAsyncWithHttpInfo
     *
     * A day of UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $date An date formatted as a RFC3339 date value. (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function pointsLatitudelongitudeDaysDateGetAsyncWithHttpInfo($latitude, $longitude, $date, $fields, $unit_scale = 'IMPERIAL')
    {
        $returnType = '\Swagger\Client\Model\UvPointDayObj';
        $request = $this->pointsLatitudelongitudeDaysDateGetRequest($latitude, $longitude, $date, $fields, $unit_scale);

        return $this->client
            ->sendAsync($request, $this->createHttpClientOption())
            ->then(
                function ($response) use ($returnType) {
                    $responseBody = $response->getBody();
                    if ($returnType === '\SplFileObject') {
                        $content = $responseBody; //stream goes to serializer
                    } else {
                        $content = $responseBody->getContents();
                        if ($returnType !== 'string') {
                            $content = json_decode($content);
                        }
                    }

                    return [
                        ObjectSerializer::deserialize($content, $returnType, []),
                        $response->getStatusCode(),
                        $response->getHeaders()
                    ];
                },
                function ($exception) {
                    $response = $exception->getResponse();
                    $statusCode = $response->getStatusCode();
                    throw new ApiException(
                        sprintf(
                            '[%d] Error connecting to the API (%s)',
                            $statusCode,
                            $exception->getRequest()->getUri()
                        ),
                        $statusCode,
                        $response->getHeaders(),
                        $response->getBody()
                    );
                }
            );
    }

    /**
     * Create request for operation 'pointsLatitudelongitudeDaysDateGet'
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $date An date formatted as a RFC3339 date value. (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Psr7\Request
     */
    protected function pointsLatitudelongitudeDaysDateGetRequest($latitude, $longitude, $date, $fields, $unit_scale = 'IMPERIAL')
    {
        // verify the required parameter 'latitude' is set
        if ($latitude === null || (is_array($latitude) && count($latitude) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $latitude when calling pointsLatitudelongitudeDaysDateGet'
            );
        }
        // verify the required parameter 'longitude' is set
        if ($longitude === null || (is_array($longitude) && count($longitude) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $longitude when calling pointsLatitudelongitudeDaysDateGet'
            );
        }
        // verify the required parameter 'date' is set
        if ($date === null || (is_array($date) && count($date) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $date when calling pointsLatitudelongitudeDaysDateGet'
            );
        }
        // verify the required parameter 'fields' is set
        if ($fields === null || (is_array($fields) && count($fields) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $fields when calling pointsLatitudelongitudeDaysDateGet'
            );
        }

        $resourcePath = '/points/{latitude},{longitude}/days/{date}';
        $formParams = [];
        $queryParams = [];
        $headerParams = [];
        $httpBody = '';
        $multipart = false;

        // query params
        if (is_array($fields)) {
            $fields = ObjectSerializer::serializeCollection($fields, 'csv', true);
        }
        if ($fields !== null) {
            $queryParams['fields'] = ObjectSerializer::toQueryValue($fields, null);
        }
        // query params
        if ($unit_scale !== null) {
            $queryParams['unitScale'] = ObjectSerializer::toQueryValue($unit_scale, null);
        }

        // path params
        if ($latitude !== null) {
            $resourcePath = str_replace(
                '{' . 'latitude' . '}',
                ObjectSerializer::toPathValue($latitude),
                $resourcePath
            );
        }
        // path params
        if ($longitude !== null) {
            $resourcePath = str_replace(
                '{' . 'longitude' . '}',
                ObjectSerializer::toPathValue($longitude),
                $resourcePath
            );
        }
        // path params
        if ($date !== null) {
            $resourcePath = str_replace(
                '{' . 'date' . '}',
                ObjectSerializer::toPathValue($date),
                $resourcePath
            );
        }

        // body params
        $_tempBody = null;

        if ($multipart) {
            $headers = $this->headerSelector->selectHeadersForMultipart(
                ['application/json']
            );
        } else {
            $headers = $this->headerSelector->selectHeaders(
                ['application/json'],
                []
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            // $_tempBody is the method argument, if present
            $httpBody = $_tempBody;
            // \stdClass has no __toString(), so we should encode it manually
            if ($httpBody instanceof \stdClass && $headers['Content-Type'] === 'application/json') {
                $httpBody = \GuzzleHttp\json_encode($httpBody);
            }
        } elseif (count($formParams) > 0) {
            if ($multipart) {
                $multipartContents = [];
                foreach ($formParams as $formParamName => $formParamValue) {
                    $multipartContents[] = [
                        'name' => $formParamName,
                        'contents' => $formParamValue
                    ];
                }
                // for HTTP post (form)
                $httpBody = new MultipartStream($multipartContents);

            } elseif ($headers['Content-Type'] === 'application/json') {
                $httpBody = \GuzzleHttp\json_encode($formParams);

            } else {
                // for HTTP post (form)
                $httpBody = \GuzzleHttp\Psr7\build_query($formParams);
            }
        }

        // this endpoint requires API key authentication
        $apiKey = $this->config->getApiKeyWithPrefix('X-API-KEY');
        if ($apiKey !== null) {
            $headers['X-API-KEY'] = $apiKey;
        }

        $defaultHeaders = [];
        if ($this->config->getUserAgent()) {
            $defaultHeaders['User-Agent'] = $this->config->getUserAgent();
        }

        $headers = array_merge(
            $defaultHeaders,
            $headerParams,
            $headers
        );

        $query = \GuzzleHttp\Psr7\build_query($queryParams);
        return new Request(
            'GET',
            $this->config->getHost() . $resourcePath . ($query ? "?{$query}" : ''),
            $headers,
            $httpBody
        );
    }

    /**
     * Operation pointsLatitudelongitudeDaysDateStartdateEndGet
     *
     * A contiguous range of daily UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $date_start An date formatted as a RFC3339 date value that must occur temporally before dateEnd. (required)
     * @param  \DateTime $date_end An date formatted as a RFC3339 date value that must occur temporally after dateStart. (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \Swagger\Client\ApiException on non-2xx response
     * @throws \InvalidArgumentException
     * @return \Swagger\Client\Model\UvPointDayObj
     */
    public function pointsLatitudelongitudeDaysDateStartdateEndGet($latitude, $longitude, $date_start, $date_end, $fields, $unit_scale = 'IMPERIAL')
    {
        list($response) = $this->pointsLatitudelongitudeDaysDateStartdateEndGetWithHttpInfo($latitude, $longitude, $date_start, $date_end, $fields, $unit_scale);
        return $response;
    }

    /**
     * Operation pointsLatitudelongitudeDaysDateStartdateEndGetWithHttpInfo
     *
     * A contiguous range of daily UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $date_start An date formatted as a RFC3339 date value that must occur temporally before dateEnd. (required)
     * @param  \DateTime $date_end An date formatted as a RFC3339 date value that must occur temporally after dateStart. (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \Swagger\Client\ApiException on non-2xx response
     * @throws \InvalidArgumentException
     * @return array of \Swagger\Client\Model\UvPointDayObj, HTTP status code, HTTP response headers (array of strings)
     */
    public function pointsLatitudelongitudeDaysDateStartdateEndGetWithHttpInfo($latitude, $longitude, $date_start, $date_end, $fields, $unit_scale = 'IMPERIAL')
    {
        $returnType = '\Swagger\Client\Model\UvPointDayObj';
        $request = $this->pointsLatitudelongitudeDaysDateStartdateEndGetRequest($latitude, $longitude, $date_start, $date_end, $fields, $unit_scale);

        try {
            $options = $this->createHttpClientOption();
            try {
                $response = $this->client->send($request, $options);
            } catch (RequestException $e) {
                throw new ApiException(
                    "[{$e->getCode()}] {$e->getMessage()}",
                    $e->getCode(),
                    $e->getResponse() ? $e->getResponse()->getHeaders() : null,
                    $e->getResponse() ? $e->getResponse()->getBody()->getContents() : null
                );
            }

            $statusCode = $response->getStatusCode();

            if ($statusCode < 200 || $statusCode > 299) {
                throw new ApiException(
                    sprintf(
                        '[%d] Error connecting to the API (%s)',
                        $statusCode,
                        $request->getUri()
                    ),
                    $statusCode,
                    $response->getHeaders(),
                    $response->getBody()
                );
            }

            $responseBody = $response->getBody();
            if ($returnType === '\SplFileObject') {
                $content = $responseBody; //stream goes to serializer
            } else {
                $content = $responseBody->getContents();
                if (!in_array($returnType, ['string','integer','bool'])) {
                    $content = json_decode($content);
                }
            }

            return [
                ObjectSerializer::deserialize($content, $returnType, []),
                $response->getStatusCode(),
                $response->getHeaders()
            ];

        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = ObjectSerializer::deserialize(
                        $e->getResponseBody(),
                        '\Swagger\Client\Model\UvPointDayObj',
                        $e->getResponseHeaders()
                    );
                    $e->setResponseObject($data);
                    break;
                case 0:
                    $data = ObjectSerializer::deserialize(
                        $e->getResponseBody(),
                        '\Swagger\Client\Model\ErrorObj',
                        $e->getResponseHeaders()
                    );
                    $e->setResponseObject($data);
                    break;
            }
            throw $e;
        }
    }

    /**
     * Operation pointsLatitudelongitudeDaysDateStartdateEndGetAsync
     *
     * A contiguous range of daily UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $date_start An date formatted as a RFC3339 date value that must occur temporally before dateEnd. (required)
     * @param  \DateTime $date_end An date formatted as a RFC3339 date value that must occur temporally after dateStart. (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function pointsLatitudelongitudeDaysDateStartdateEndGetAsync($latitude, $longitude, $date_start, $date_end, $fields, $unit_scale = 'IMPERIAL')
    {
        return $this->pointsLatitudelongitudeDaysDateStartdateEndGetAsyncWithHttpInfo($latitude, $longitude, $date_start, $date_end, $fields, $unit_scale)
            ->then(
                function ($response) {
                    return $response[0];
                }
            );
    }

    /**
     * Operation pointsLatitudelongitudeDaysDateStartdateEndGetAsyncWithHttpInfo
     *
     * A contiguous range of daily UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $date_start An date formatted as a RFC3339 date value that must occur temporally before dateEnd. (required)
     * @param  \DateTime $date_end An date formatted as a RFC3339 date value that must occur temporally after dateStart. (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function pointsLatitudelongitudeDaysDateStartdateEndGetAsyncWithHttpInfo($latitude, $longitude, $date_start, $date_end, $fields, $unit_scale = 'IMPERIAL')
    {
        $returnType = '\Swagger\Client\Model\UvPointDayObj';
        $request = $this->pointsLatitudelongitudeDaysDateStartdateEndGetRequest($latitude, $longitude, $date_start, $date_end, $fields, $unit_scale);

        return $this->client
            ->sendAsync($request, $this->createHttpClientOption())
            ->then(
                function ($response) use ($returnType) {
                    $responseBody = $response->getBody();
                    if ($returnType === '\SplFileObject') {
                        $content = $responseBody; //stream goes to serializer
                    } else {
                        $content = $responseBody->getContents();
                        if ($returnType !== 'string') {
                            $content = json_decode($content);
                        }
                    }

                    return [
                        ObjectSerializer::deserialize($content, $returnType, []),
                        $response->getStatusCode(),
                        $response->getHeaders()
                    ];
                },
                function ($exception) {
                    $response = $exception->getResponse();
                    $statusCode = $response->getStatusCode();
                    throw new ApiException(
                        sprintf(
                            '[%d] Error connecting to the API (%s)',
                            $statusCode,
                            $exception->getRequest()->getUri()
                        ),
                        $statusCode,
                        $response->getHeaders(),
                        $response->getBody()
                    );
                }
            );
    }

    /**
     * Create request for operation 'pointsLatitudelongitudeDaysDateStartdateEndGet'
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $date_start An date formatted as a RFC3339 date value that must occur temporally before dateEnd. (required)
     * @param  \DateTime $date_end An date formatted as a RFC3339 date value that must occur temporally after dateStart. (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Psr7\Request
     */
    protected function pointsLatitudelongitudeDaysDateStartdateEndGetRequest($latitude, $longitude, $date_start, $date_end, $fields, $unit_scale = 'IMPERIAL')
    {
        // verify the required parameter 'latitude' is set
        if ($latitude === null || (is_array($latitude) && count($latitude) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $latitude when calling pointsLatitudelongitudeDaysDateStartdateEndGet'
            );
        }
        // verify the required parameter 'longitude' is set
        if ($longitude === null || (is_array($longitude) && count($longitude) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $longitude when calling pointsLatitudelongitudeDaysDateStartdateEndGet'
            );
        }
        // verify the required parameter 'date_start' is set
        if ($date_start === null || (is_array($date_start) && count($date_start) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $date_start when calling pointsLatitudelongitudeDaysDateStartdateEndGet'
            );
        }
        // verify the required parameter 'date_end' is set
        if ($date_end === null || (is_array($date_end) && count($date_end) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $date_end when calling pointsLatitudelongitudeDaysDateStartdateEndGet'
            );
        }
        // verify the required parameter 'fields' is set
        if ($fields === null || (is_array($fields) && count($fields) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $fields when calling pointsLatitudelongitudeDaysDateStartdateEndGet'
            );
        }

        $resourcePath = '/points/{latitude},{longitude}/days/{dateStart},{dateEnd}';
        $formParams = [];
        $queryParams = [];
        $headerParams = [];
        $httpBody = '';
        $multipart = false;

        // query params
        if (is_array($fields)) {
            $fields = ObjectSerializer::serializeCollection($fields, 'csv', true);
        }
        if ($fields !== null) {
            $queryParams['fields'] = ObjectSerializer::toQueryValue($fields, null);
        }
        // query params
        if ($unit_scale !== null) {
            $queryParams['unitScale'] = ObjectSerializer::toQueryValue($unit_scale, null);
        }

        // path params
        if ($latitude !== null) {
            $resourcePath = str_replace(
                '{' . 'latitude' . '}',
                ObjectSerializer::toPathValue($latitude),
                $resourcePath
            );
        }
        // path params
        if ($longitude !== null) {
            $resourcePath = str_replace(
                '{' . 'longitude' . '}',
                ObjectSerializer::toPathValue($longitude),
                $resourcePath
            );
        }
        // path params
        if ($date_start !== null) {
            $resourcePath = str_replace(
                '{' . 'dateStart' . '}',
                ObjectSerializer::toPathValue($date_start),
                $resourcePath
            );
        }
        // path params
        if ($date_end !== null) {
            $resourcePath = str_replace(
                '{' . 'dateEnd' . '}',
                ObjectSerializer::toPathValue($date_end),
                $resourcePath
            );
        }

        // body params
        $_tempBody = null;

        if ($multipart) {
            $headers = $this->headerSelector->selectHeadersForMultipart(
                ['application/json']
            );
        } else {
            $headers = $this->headerSelector->selectHeaders(
                ['application/json'],
                []
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            // $_tempBody is the method argument, if present
            $httpBody = $_tempBody;
            // \stdClass has no __toString(), so we should encode it manually
            if ($httpBody instanceof \stdClass && $headers['Content-Type'] === 'application/json') {
                $httpBody = \GuzzleHttp\json_encode($httpBody);
            }
        } elseif (count($formParams) > 0) {
            if ($multipart) {
                $multipartContents = [];
                foreach ($formParams as $formParamName => $formParamValue) {
                    $multipartContents[] = [
                        'name' => $formParamName,
                        'contents' => $formParamValue
                    ];
                }
                // for HTTP post (form)
                $httpBody = new MultipartStream($multipartContents);

            } elseif ($headers['Content-Type'] === 'application/json') {
                $httpBody = \GuzzleHttp\json_encode($formParams);

            } else {
                // for HTTP post (form)
                $httpBody = \GuzzleHttp\Psr7\build_query($formParams);
            }
        }

        // this endpoint requires API key authentication
        $apiKey = $this->config->getApiKeyWithPrefix('X-API-KEY');
        if ($apiKey !== null) {
            $headers['X-API-KEY'] = $apiKey;
        }

        $defaultHeaders = [];
        if ($this->config->getUserAgent()) {
            $defaultHeaders['User-Agent'] = $this->config->getUserAgent();
        }

        $headers = array_merge(
            $defaultHeaders,
            $headerParams,
            $headers
        );

        $query = \GuzzleHttp\Psr7\build_query($queryParams);
        return new Request(
            'GET',
            $this->config->getHost() . $resourcePath . ($query ? "?{$query}" : ''),
            $headers,
            $httpBody
        );
    }

    /**
     * Operation pointsLatitudelongitudeDaysGet
     *
     * The complete daily UV forecast for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \Swagger\Client\ApiException on non-2xx response
     * @throws \InvalidArgumentException
     * @return \Swagger\Client\Model\UvPointDayObj
     */
    public function pointsLatitudelongitudeDaysGet($latitude, $longitude, $fields, $unit_scale = 'IMPERIAL')
    {
        list($response) = $this->pointsLatitudelongitudeDaysGetWithHttpInfo($latitude, $longitude, $fields, $unit_scale);
        return $response;
    }

    /**
     * Operation pointsLatitudelongitudeDaysGetWithHttpInfo
     *
     * The complete daily UV forecast for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \Swagger\Client\ApiException on non-2xx response
     * @throws \InvalidArgumentException
     * @return array of \Swagger\Client\Model\UvPointDayObj, HTTP status code, HTTP response headers (array of strings)
     */
    public function pointsLatitudelongitudeDaysGetWithHttpInfo($latitude, $longitude, $fields, $unit_scale = 'IMPERIAL')
    {
        $returnType = '\Swagger\Client\Model\UvPointDayObj';
        $request = $this->pointsLatitudelongitudeDaysGetRequest($latitude, $longitude, $fields, $unit_scale);

        try {
            $options = $this->createHttpClientOption();
            try {
                $response = $this->client->send($request, $options);
            } catch (RequestException $e) {
                throw new ApiException(
                    "[{$e->getCode()}] {$e->getMessage()}",
                    $e->getCode(),
                    $e->getResponse() ? $e->getResponse()->getHeaders() : null,
                    $e->getResponse() ? $e->getResponse()->getBody()->getContents() : null
                );
            }

            $statusCode = $response->getStatusCode();

            if ($statusCode < 200 || $statusCode > 299) {
                throw new ApiException(
                    sprintf(
                        '[%d] Error connecting to the API (%s)',
                        $statusCode,
                        $request->getUri()
                    ),
                    $statusCode,
                    $response->getHeaders(),
                    $response->getBody()
                );
            }

            $responseBody = $response->getBody();
            if ($returnType === '\SplFileObject') {
                $content = $responseBody; //stream goes to serializer
            } else {
                $content = $responseBody->getContents();
                if (!in_array($returnType, ['string','integer','bool'])) {
                    $content = json_decode($content);
                }
            }

            return [
                ObjectSerializer::deserialize($content, $returnType, []),
                $response->getStatusCode(),
                $response->getHeaders()
            ];

        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = ObjectSerializer::deserialize(
                        $e->getResponseBody(),
                        '\Swagger\Client\Model\UvPointDayObj',
                        $e->getResponseHeaders()
                    );
                    $e->setResponseObject($data);
                    break;
                case 0:
                    $data = ObjectSerializer::deserialize(
                        $e->getResponseBody(),
                        '\Swagger\Client\Model\ErrorObj',
                        $e->getResponseHeaders()
                    );
                    $e->setResponseObject($data);
                    break;
            }
            throw $e;
        }
    }

    /**
     * Operation pointsLatitudelongitudeDaysGetAsync
     *
     * The complete daily UV forecast for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function pointsLatitudelongitudeDaysGetAsync($latitude, $longitude, $fields, $unit_scale = 'IMPERIAL')
    {
        return $this->pointsLatitudelongitudeDaysGetAsyncWithHttpInfo($latitude, $longitude, $fields, $unit_scale)
            ->then(
                function ($response) {
                    return $response[0];
                }
            );
    }

    /**
     * Operation pointsLatitudelongitudeDaysGetAsyncWithHttpInfo
     *
     * The complete daily UV forecast for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function pointsLatitudelongitudeDaysGetAsyncWithHttpInfo($latitude, $longitude, $fields, $unit_scale = 'IMPERIAL')
    {
        $returnType = '\Swagger\Client\Model\UvPointDayObj';
        $request = $this->pointsLatitudelongitudeDaysGetRequest($latitude, $longitude, $fields, $unit_scale);

        return $this->client
            ->sendAsync($request, $this->createHttpClientOption())
            ->then(
                function ($response) use ($returnType) {
                    $responseBody = $response->getBody();
                    if ($returnType === '\SplFileObject') {
                        $content = $responseBody; //stream goes to serializer
                    } else {
                        $content = $responseBody->getContents();
                        if ($returnType !== 'string') {
                            $content = json_decode($content);
                        }
                    }

                    return [
                        ObjectSerializer::deserialize($content, $returnType, []),
                        $response->getStatusCode(),
                        $response->getHeaders()
                    ];
                },
                function ($exception) {
                    $response = $exception->getResponse();
                    $statusCode = $response->getStatusCode();
                    throw new ApiException(
                        sprintf(
                            '[%d] Error connecting to the API (%s)',
                            $statusCode,
                            $exception->getRequest()->getUri()
                        ),
                        $statusCode,
                        $response->getHeaders(),
                        $response->getBody()
                    );
                }
            );
    }

    /**
     * Create request for operation 'pointsLatitudelongitudeDaysGet'
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  string[] $fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Psr7\Request
     */
    protected function pointsLatitudelongitudeDaysGetRequest($latitude, $longitude, $fields, $unit_scale = 'IMPERIAL')
    {
        // verify the required parameter 'latitude' is set
        if ($latitude === null || (is_array($latitude) && count($latitude) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $latitude when calling pointsLatitudelongitudeDaysGet'
            );
        }
        // verify the required parameter 'longitude' is set
        if ($longitude === null || (is_array($longitude) && count($longitude) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $longitude when calling pointsLatitudelongitudeDaysGet'
            );
        }
        // verify the required parameter 'fields' is set
        if ($fields === null || (is_array($fields) && count($fields) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $fields when calling pointsLatitudelongitudeDaysGet'
            );
        }

        $resourcePath = '/points/{latitude},{longitude}/days';
        $formParams = [];
        $queryParams = [];
        $headerParams = [];
        $httpBody = '';
        $multipart = false;

        // query params
        if (is_array($fields)) {
            $fields = ObjectSerializer::serializeCollection($fields, 'csv', true);
        }
        if ($fields !== null) {
            $queryParams['fields'] = ObjectSerializer::toQueryValue($fields, null);
        }
        // query params
        if ($unit_scale !== null) {
            $queryParams['unitScale'] = ObjectSerializer::toQueryValue($unit_scale, null);
        }

        // path params
        if ($latitude !== null) {
            $resourcePath = str_replace(
                '{' . 'latitude' . '}',
                ObjectSerializer::toPathValue($latitude),
                $resourcePath
            );
        }
        // path params
        if ($longitude !== null) {
            $resourcePath = str_replace(
                '{' . 'longitude' . '}',
                ObjectSerializer::toPathValue($longitude),
                $resourcePath
            );
        }

        // body params
        $_tempBody = null;

        if ($multipart) {
            $headers = $this->headerSelector->selectHeadersForMultipart(
                ['application/json']
            );
        } else {
            $headers = $this->headerSelector->selectHeaders(
                ['application/json'],
                []
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            // $_tempBody is the method argument, if present
            $httpBody = $_tempBody;
            // \stdClass has no __toString(), so we should encode it manually
            if ($httpBody instanceof \stdClass && $headers['Content-Type'] === 'application/json') {
                $httpBody = \GuzzleHttp\json_encode($httpBody);
            }
        } elseif (count($formParams) > 0) {
            if ($multipart) {
                $multipartContents = [];
                foreach ($formParams as $formParamName => $formParamValue) {
                    $multipartContents[] = [
                        'name' => $formParamName,
                        'contents' => $formParamValue
                    ];
                }
                // for HTTP post (form)
                $httpBody = new MultipartStream($multipartContents);

            } elseif ($headers['Content-Type'] === 'application/json') {
                $httpBody = \GuzzleHttp\json_encode($formParams);

            } else {
                // for HTTP post (form)
                $httpBody = \GuzzleHttp\Psr7\build_query($formParams);
            }
        }

        // this endpoint requires API key authentication
        $apiKey = $this->config->getApiKeyWithPrefix('X-API-KEY');
        if ($apiKey !== null) {
            $headers['X-API-KEY'] = $apiKey;
        }

        $defaultHeaders = [];
        if ($this->config->getUserAgent()) {
            $defaultHeaders['User-Agent'] = $this->config->getUserAgent();
        }

        $headers = array_merge(
            $defaultHeaders,
            $headerParams,
            $headers
        );

        $query = \GuzzleHttp\Psr7\build_query($queryParams);
        return new Request(
            'GET',
            $this->config->getHost() . $resourcePath . ($query ? "?{$query}" : ''),
            $headers,
            $httpBody
        );
    }

    /**
     * Operation pointsLatitudelongitudeHoursGet
     *
     * The complete hourly UV forecast for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \Swagger\Client\ApiException on non-2xx response
     * @throws \InvalidArgumentException
     * @return \Swagger\Client\Model\UvPointHourObj
     */
    public function pointsLatitudelongitudeHoursGet($latitude, $longitude, $fields, $unit_scale = 'IMPERIAL')
    {
        list($response) = $this->pointsLatitudelongitudeHoursGetWithHttpInfo($latitude, $longitude, $fields, $unit_scale);
        return $response;
    }

    /**
     * Operation pointsLatitudelongitudeHoursGetWithHttpInfo
     *
     * The complete hourly UV forecast for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \Swagger\Client\ApiException on non-2xx response
     * @throws \InvalidArgumentException
     * @return array of \Swagger\Client\Model\UvPointHourObj, HTTP status code, HTTP response headers (array of strings)
     */
    public function pointsLatitudelongitudeHoursGetWithHttpInfo($latitude, $longitude, $fields, $unit_scale = 'IMPERIAL')
    {
        $returnType = '\Swagger\Client\Model\UvPointHourObj';
        $request = $this->pointsLatitudelongitudeHoursGetRequest($latitude, $longitude, $fields, $unit_scale);

        try {
            $options = $this->createHttpClientOption();
            try {
                $response = $this->client->send($request, $options);
            } catch (RequestException $e) {
                throw new ApiException(
                    "[{$e->getCode()}] {$e->getMessage()}",
                    $e->getCode(),
                    $e->getResponse() ? $e->getResponse()->getHeaders() : null,
                    $e->getResponse() ? $e->getResponse()->getBody()->getContents() : null
                );
            }

            $statusCode = $response->getStatusCode();

            if ($statusCode < 200 || $statusCode > 299) {
                throw new ApiException(
                    sprintf(
                        '[%d] Error connecting to the API (%s)',
                        $statusCode,
                        $request->getUri()
                    ),
                    $statusCode,
                    $response->getHeaders(),
                    $response->getBody()
                );
            }

            $responseBody = $response->getBody();
            if ($returnType === '\SplFileObject') {
                $content = $responseBody; //stream goes to serializer
            } else {
                $content = $responseBody->getContents();
                if (!in_array($returnType, ['string','integer','bool'])) {
                    $content = json_decode($content);
                }
            }

            return [
                ObjectSerializer::deserialize($content, $returnType, []),
                $response->getStatusCode(),
                $response->getHeaders()
            ];

        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = ObjectSerializer::deserialize(
                        $e->getResponseBody(),
                        '\Swagger\Client\Model\UvPointHourObj',
                        $e->getResponseHeaders()
                    );
                    $e->setResponseObject($data);
                    break;
                case 0:
                    $data = ObjectSerializer::deserialize(
                        $e->getResponseBody(),
                        '\Swagger\Client\Model\ErrorObj',
                        $e->getResponseHeaders()
                    );
                    $e->setResponseObject($data);
                    break;
            }
            throw $e;
        }
    }

    /**
     * Operation pointsLatitudelongitudeHoursGetAsync
     *
     * The complete hourly UV forecast for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function pointsLatitudelongitudeHoursGetAsync($latitude, $longitude, $fields, $unit_scale = 'IMPERIAL')
    {
        return $this->pointsLatitudelongitudeHoursGetAsyncWithHttpInfo($latitude, $longitude, $fields, $unit_scale)
            ->then(
                function ($response) {
                    return $response[0];
                }
            );
    }

    /**
     * Operation pointsLatitudelongitudeHoursGetAsyncWithHttpInfo
     *
     * The complete hourly UV forecast for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function pointsLatitudelongitudeHoursGetAsyncWithHttpInfo($latitude, $longitude, $fields, $unit_scale = 'IMPERIAL')
    {
        $returnType = '\Swagger\Client\Model\UvPointHourObj';
        $request = $this->pointsLatitudelongitudeHoursGetRequest($latitude, $longitude, $fields, $unit_scale);

        return $this->client
            ->sendAsync($request, $this->createHttpClientOption())
            ->then(
                function ($response) use ($returnType) {
                    $responseBody = $response->getBody();
                    if ($returnType === '\SplFileObject') {
                        $content = $responseBody; //stream goes to serializer
                    } else {
                        $content = $responseBody->getContents();
                        if ($returnType !== 'string') {
                            $content = json_decode($content);
                        }
                    }

                    return [
                        ObjectSerializer::deserialize($content, $returnType, []),
                        $response->getStatusCode(),
                        $response->getHeaders()
                    ];
                },
                function ($exception) {
                    $response = $exception->getResponse();
                    $statusCode = $response->getStatusCode();
                    throw new ApiException(
                        sprintf(
                            '[%d] Error connecting to the API (%s)',
                            $statusCode,
                            $exception->getRequest()->getUri()
                        ),
                        $statusCode,
                        $response->getHeaders(),
                        $response->getBody()
                    );
                }
            );
    }

    /**
     * Create request for operation 'pointsLatitudelongitudeHoursGet'
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Psr7\Request
     */
    protected function pointsLatitudelongitudeHoursGetRequest($latitude, $longitude, $fields, $unit_scale = 'IMPERIAL')
    {
        // verify the required parameter 'latitude' is set
        if ($latitude === null || (is_array($latitude) && count($latitude) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $latitude when calling pointsLatitudelongitudeHoursGet'
            );
        }
        // verify the required parameter 'longitude' is set
        if ($longitude === null || (is_array($longitude) && count($longitude) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $longitude when calling pointsLatitudelongitudeHoursGet'
            );
        }
        // verify the required parameter 'fields' is set
        if ($fields === null || (is_array($fields) && count($fields) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $fields when calling pointsLatitudelongitudeHoursGet'
            );
        }

        $resourcePath = '/points/{latitude},{longitude}/hours';
        $formParams = [];
        $queryParams = [];
        $headerParams = [];
        $httpBody = '';
        $multipart = false;

        // query params
        if (is_array($fields)) {
            $fields = ObjectSerializer::serializeCollection($fields, 'csv', true);
        }
        if ($fields !== null) {
            $queryParams['fields'] = ObjectSerializer::toQueryValue($fields, null);
        }
        // query params
        if ($unit_scale !== null) {
            $queryParams['unitScale'] = ObjectSerializer::toQueryValue($unit_scale, null);
        }

        // path params
        if ($latitude !== null) {
            $resourcePath = str_replace(
                '{' . 'latitude' . '}',
                ObjectSerializer::toPathValue($latitude),
                $resourcePath
            );
        }
        // path params
        if ($longitude !== null) {
            $resourcePath = str_replace(
                '{' . 'longitude' . '}',
                ObjectSerializer::toPathValue($longitude),
                $resourcePath
            );
        }

        // body params
        $_tempBody = null;

        if ($multipart) {
            $headers = $this->headerSelector->selectHeadersForMultipart(
                ['application/json']
            );
        } else {
            $headers = $this->headerSelector->selectHeaders(
                ['application/json'],
                []
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            // $_tempBody is the method argument, if present
            $httpBody = $_tempBody;
            // \stdClass has no __toString(), so we should encode it manually
            if ($httpBody instanceof \stdClass && $headers['Content-Type'] === 'application/json') {
                $httpBody = \GuzzleHttp\json_encode($httpBody);
            }
        } elseif (count($formParams) > 0) {
            if ($multipart) {
                $multipartContents = [];
                foreach ($formParams as $formParamName => $formParamValue) {
                    $multipartContents[] = [
                        'name' => $formParamName,
                        'contents' => $formParamValue
                    ];
                }
                // for HTTP post (form)
                $httpBody = new MultipartStream($multipartContents);

            } elseif ($headers['Content-Type'] === 'application/json') {
                $httpBody = \GuzzleHttp\json_encode($formParams);

            } else {
                // for HTTP post (form)
                $httpBody = \GuzzleHttp\Psr7\build_query($formParams);
            }
        }

        // this endpoint requires API key authentication
        $apiKey = $this->config->getApiKeyWithPrefix('X-API-KEY');
        if ($apiKey !== null) {
            $headers['X-API-KEY'] = $apiKey;
        }

        $defaultHeaders = [];
        if ($this->config->getUserAgent()) {
            $defaultHeaders['User-Agent'] = $this->config->getUserAgent();
        }

        $headers = array_merge(
            $defaultHeaders,
            $headerParams,
            $headers
        );

        $query = \GuzzleHttp\Psr7\build_query($queryParams);
        return new Request(
            'GET',
            $this->config->getHost() . $resourcePath . ($query ? "?{$query}" : ''),
            $headers,
            $httpBody
        );
    }

    /**
     * Operation pointsLatitudelongitudeHoursTimestampGet
     *
     * An hour of UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \Swagger\Client\ApiException on non-2xx response
     * @throws \InvalidArgumentException
     * @return \Swagger\Client\Model\UvPointHourObj
     */
    public function pointsLatitudelongitudeHoursTimestampGet($latitude, $longitude, $timestamp, $fields, $unit_scale = 'IMPERIAL')
    {
        list($response) = $this->pointsLatitudelongitudeHoursTimestampGetWithHttpInfo($latitude, $longitude, $timestamp, $fields, $unit_scale);
        return $response;
    }

    /**
     * Operation pointsLatitudelongitudeHoursTimestampGetWithHttpInfo
     *
     * An hour of UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \Swagger\Client\ApiException on non-2xx response
     * @throws \InvalidArgumentException
     * @return array of \Swagger\Client\Model\UvPointHourObj, HTTP status code, HTTP response headers (array of strings)
     */
    public function pointsLatitudelongitudeHoursTimestampGetWithHttpInfo($latitude, $longitude, $timestamp, $fields, $unit_scale = 'IMPERIAL')
    {
        $returnType = '\Swagger\Client\Model\UvPointHourObj';
        $request = $this->pointsLatitudelongitudeHoursTimestampGetRequest($latitude, $longitude, $timestamp, $fields, $unit_scale);

        try {
            $options = $this->createHttpClientOption();
            try {
                $response = $this->client->send($request, $options);
            } catch (RequestException $e) {
                throw new ApiException(
                    "[{$e->getCode()}] {$e->getMessage()}",
                    $e->getCode(),
                    $e->getResponse() ? $e->getResponse()->getHeaders() : null,
                    $e->getResponse() ? $e->getResponse()->getBody()->getContents() : null
                );
            }

            $statusCode = $response->getStatusCode();

            if ($statusCode < 200 || $statusCode > 299) {
                throw new ApiException(
                    sprintf(
                        '[%d] Error connecting to the API (%s)',
                        $statusCode,
                        $request->getUri()
                    ),
                    $statusCode,
                    $response->getHeaders(),
                    $response->getBody()
                );
            }

            $responseBody = $response->getBody();
            if ($returnType === '\SplFileObject') {
                $content = $responseBody; //stream goes to serializer
            } else {
                $content = $responseBody->getContents();
                if (!in_array($returnType, ['string','integer','bool'])) {
                    $content = json_decode($content);
                }
            }

            return [
                ObjectSerializer::deserialize($content, $returnType, []),
                $response->getStatusCode(),
                $response->getHeaders()
            ];

        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = ObjectSerializer::deserialize(
                        $e->getResponseBody(),
                        '\Swagger\Client\Model\UvPointHourObj',
                        $e->getResponseHeaders()
                    );
                    $e->setResponseObject($data);
                    break;
                case 0:
                    $data = ObjectSerializer::deserialize(
                        $e->getResponseBody(),
                        '\Swagger\Client\Model\ErrorObj',
                        $e->getResponseHeaders()
                    );
                    $e->setResponseObject($data);
                    break;
            }
            throw $e;
        }
    }

    /**
     * Operation pointsLatitudelongitudeHoursTimestampGetAsync
     *
     * An hour of UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function pointsLatitudelongitudeHoursTimestampGetAsync($latitude, $longitude, $timestamp, $fields, $unit_scale = 'IMPERIAL')
    {
        return $this->pointsLatitudelongitudeHoursTimestampGetAsyncWithHttpInfo($latitude, $longitude, $timestamp, $fields, $unit_scale)
            ->then(
                function ($response) {
                    return $response[0];
                }
            );
    }

    /**
     * Operation pointsLatitudelongitudeHoursTimestampGetAsyncWithHttpInfo
     *
     * An hour of UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function pointsLatitudelongitudeHoursTimestampGetAsyncWithHttpInfo($latitude, $longitude, $timestamp, $fields, $unit_scale = 'IMPERIAL')
    {
        $returnType = '\Swagger\Client\Model\UvPointHourObj';
        $request = $this->pointsLatitudelongitudeHoursTimestampGetRequest($latitude, $longitude, $timestamp, $fields, $unit_scale);

        return $this->client
            ->sendAsync($request, $this->createHttpClientOption())
            ->then(
                function ($response) use ($returnType) {
                    $responseBody = $response->getBody();
                    if ($returnType === '\SplFileObject') {
                        $content = $responseBody; //stream goes to serializer
                    } else {
                        $content = $responseBody->getContents();
                        if ($returnType !== 'string') {
                            $content = json_decode($content);
                        }
                    }

                    return [
                        ObjectSerializer::deserialize($content, $returnType, []),
                        $response->getStatusCode(),
                        $response->getHeaders()
                    ];
                },
                function ($exception) {
                    $response = $exception->getResponse();
                    $statusCode = $response->getStatusCode();
                    throw new ApiException(
                        sprintf(
                            '[%d] Error connecting to the API (%s)',
                            $statusCode,
                            $exception->getRequest()->getUri()
                        ),
                        $statusCode,
                        $response->getHeaders(),
                        $response->getBody()
                    );
                }
            );
    }

    /**
     * Create request for operation 'pointsLatitudelongitudeHoursTimestampGet'
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required. (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Psr7\Request
     */
    protected function pointsLatitudelongitudeHoursTimestampGetRequest($latitude, $longitude, $timestamp, $fields, $unit_scale = 'IMPERIAL')
    {
        // verify the required parameter 'latitude' is set
        if ($latitude === null || (is_array($latitude) && count($latitude) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $latitude when calling pointsLatitudelongitudeHoursTimestampGet'
            );
        }
        // verify the required parameter 'longitude' is set
        if ($longitude === null || (is_array($longitude) && count($longitude) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $longitude when calling pointsLatitudelongitudeHoursTimestampGet'
            );
        }
        // verify the required parameter 'timestamp' is set
        if ($timestamp === null || (is_array($timestamp) && count($timestamp) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $timestamp when calling pointsLatitudelongitudeHoursTimestampGet'
            );
        }
        // verify the required parameter 'fields' is set
        if ($fields === null || (is_array($fields) && count($fields) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $fields when calling pointsLatitudelongitudeHoursTimestampGet'
            );
        }

        $resourcePath = '/points/{latitude},{longitude}/hours/{timestamp}';
        $formParams = [];
        $queryParams = [];
        $headerParams = [];
        $httpBody = '';
        $multipart = false;

        // query params
        if (is_array($fields)) {
            $fields = ObjectSerializer::serializeCollection($fields, 'csv', true);
        }
        if ($fields !== null) {
            $queryParams['fields'] = ObjectSerializer::toQueryValue($fields, null);
        }
        // query params
        if ($unit_scale !== null) {
            $queryParams['unitScale'] = ObjectSerializer::toQueryValue($unit_scale, null);
        }

        // path params
        if ($latitude !== null) {
            $resourcePath = str_replace(
                '{' . 'latitude' . '}',
                ObjectSerializer::toPathValue($latitude),
                $resourcePath
            );
        }
        // path params
        if ($longitude !== null) {
            $resourcePath = str_replace(
                '{' . 'longitude' . '}',
                ObjectSerializer::toPathValue($longitude),
                $resourcePath
            );
        }
        // path params
        if ($timestamp !== null) {
            $resourcePath = str_replace(
                '{' . 'timestamp' . '}',
                ObjectSerializer::toPathValue($timestamp),
                $resourcePath
            );
        }

        // body params
        $_tempBody = null;

        if ($multipart) {
            $headers = $this->headerSelector->selectHeadersForMultipart(
                ['application/json']
            );
        } else {
            $headers = $this->headerSelector->selectHeaders(
                ['application/json'],
                []
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            // $_tempBody is the method argument, if present
            $httpBody = $_tempBody;
            // \stdClass has no __toString(), so we should encode it manually
            if ($httpBody instanceof \stdClass && $headers['Content-Type'] === 'application/json') {
                $httpBody = \GuzzleHttp\json_encode($httpBody);
            }
        } elseif (count($formParams) > 0) {
            if ($multipart) {
                $multipartContents = [];
                foreach ($formParams as $formParamName => $formParamValue) {
                    $multipartContents[] = [
                        'name' => $formParamName,
                        'contents' => $formParamValue
                    ];
                }
                // for HTTP post (form)
                $httpBody = new MultipartStream($multipartContents);

            } elseif ($headers['Content-Type'] === 'application/json') {
                $httpBody = \GuzzleHttp\json_encode($formParams);

            } else {
                // for HTTP post (form)
                $httpBody = \GuzzleHttp\Psr7\build_query($formParams);
            }
        }

        // this endpoint requires API key authentication
        $apiKey = $this->config->getApiKeyWithPrefix('X-API-KEY');
        if ($apiKey !== null) {
            $headers['X-API-KEY'] = $apiKey;
        }

        $defaultHeaders = [];
        if ($this->config->getUserAgent()) {
            $defaultHeaders['User-Agent'] = $this->config->getUserAgent();
        }

        $headers = array_merge(
            $defaultHeaders,
            $headerParams,
            $headers
        );

        $query = \GuzzleHttp\Psr7\build_query($queryParams);
        return new Request(
            'GET',
            $this->config->getHost() . $resourcePath . ($query ? "?{$query}" : ''),
            $headers,
            $httpBody
        );
    }

    /**
     * Operation pointsLatitudelongitudeHoursTimestampStarttimestampEndGet
     *
     * A contiguous range of hourly UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $timestamp_start A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. (required)
     * @param  \DateTime $timestamp_end A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \Swagger\Client\ApiException on non-2xx response
     * @throws \InvalidArgumentException
     * @return \Swagger\Client\Model\UvPointHourObj
     */
    public function pointsLatitudelongitudeHoursTimestampStarttimestampEndGet($latitude, $longitude, $timestamp_start, $timestamp_end, $fields, $unit_scale = 'IMPERIAL')
    {
        list($response) = $this->pointsLatitudelongitudeHoursTimestampStarttimestampEndGetWithHttpInfo($latitude, $longitude, $timestamp_start, $timestamp_end, $fields, $unit_scale);
        return $response;
    }

    /**
     * Operation pointsLatitudelongitudeHoursTimestampStarttimestampEndGetWithHttpInfo
     *
     * A contiguous range of hourly UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $timestamp_start A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. (required)
     * @param  \DateTime $timestamp_end A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \Swagger\Client\ApiException on non-2xx response
     * @throws \InvalidArgumentException
     * @return array of \Swagger\Client\Model\UvPointHourObj, HTTP status code, HTTP response headers (array of strings)
     */
    public function pointsLatitudelongitudeHoursTimestampStarttimestampEndGetWithHttpInfo($latitude, $longitude, $timestamp_start, $timestamp_end, $fields, $unit_scale = 'IMPERIAL')
    {
        $returnType = '\Swagger\Client\Model\UvPointHourObj';
        $request = $this->pointsLatitudelongitudeHoursTimestampStarttimestampEndGetRequest($latitude, $longitude, $timestamp_start, $timestamp_end, $fields, $unit_scale);

        try {
            $options = $this->createHttpClientOption();
            try {
                $response = $this->client->send($request, $options);
            } catch (RequestException $e) {
                throw new ApiException(
                    "[{$e->getCode()}] {$e->getMessage()}",
                    $e->getCode(),
                    $e->getResponse() ? $e->getResponse()->getHeaders() : null,
                    $e->getResponse() ? $e->getResponse()->getBody()->getContents() : null
                );
            }

            $statusCode = $response->getStatusCode();

            if ($statusCode < 200 || $statusCode > 299) {
                throw new ApiException(
                    sprintf(
                        '[%d] Error connecting to the API (%s)',
                        $statusCode,
                        $request->getUri()
                    ),
                    $statusCode,
                    $response->getHeaders(),
                    $response->getBody()
                );
            }

            $responseBody = $response->getBody();
            if ($returnType === '\SplFileObject') {
                $content = $responseBody; //stream goes to serializer
            } else {
                $content = $responseBody->getContents();
                if (!in_array($returnType, ['string','integer','bool'])) {
                    $content = json_decode($content);
                }
            }

            return [
                ObjectSerializer::deserialize($content, $returnType, []),
                $response->getStatusCode(),
                $response->getHeaders()
            ];

        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = ObjectSerializer::deserialize(
                        $e->getResponseBody(),
                        '\Swagger\Client\Model\UvPointHourObj',
                        $e->getResponseHeaders()
                    );
                    $e->setResponseObject($data);
                    break;
                case 0:
                    $data = ObjectSerializer::deserialize(
                        $e->getResponseBody(),
                        '\Swagger\Client\Model\ErrorObj',
                        $e->getResponseHeaders()
                    );
                    $e->setResponseObject($data);
                    break;
            }
            throw $e;
        }
    }

    /**
     * Operation pointsLatitudelongitudeHoursTimestampStarttimestampEndGetAsync
     *
     * A contiguous range of hourly UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $timestamp_start A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. (required)
     * @param  \DateTime $timestamp_end A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function pointsLatitudelongitudeHoursTimestampStarttimestampEndGetAsync($latitude, $longitude, $timestamp_start, $timestamp_end, $fields, $unit_scale = 'IMPERIAL')
    {
        return $this->pointsLatitudelongitudeHoursTimestampStarttimestampEndGetAsyncWithHttpInfo($latitude, $longitude, $timestamp_start, $timestamp_end, $fields, $unit_scale)
            ->then(
                function ($response) {
                    return $response[0];
                }
            );
    }

    /**
     * Operation pointsLatitudelongitudeHoursTimestampStarttimestampEndGetAsyncWithHttpInfo
     *
     * A contiguous range of hourly UV data for a Latitude/Longitude point.
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $timestamp_start A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. (required)
     * @param  \DateTime $timestamp_end A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Promise\PromiseInterface
     */
    public function pointsLatitudelongitudeHoursTimestampStarttimestampEndGetAsyncWithHttpInfo($latitude, $longitude, $timestamp_start, $timestamp_end, $fields, $unit_scale = 'IMPERIAL')
    {
        $returnType = '\Swagger\Client\Model\UvPointHourObj';
        $request = $this->pointsLatitudelongitudeHoursTimestampStarttimestampEndGetRequest($latitude, $longitude, $timestamp_start, $timestamp_end, $fields, $unit_scale);

        return $this->client
            ->sendAsync($request, $this->createHttpClientOption())
            ->then(
                function ($response) use ($returnType) {
                    $responseBody = $response->getBody();
                    if ($returnType === '\SplFileObject') {
                        $content = $responseBody; //stream goes to serializer
                    } else {
                        $content = $responseBody->getContents();
                        if ($returnType !== 'string') {
                            $content = json_decode($content);
                        }
                    }

                    return [
                        ObjectSerializer::deserialize($content, $returnType, []),
                        $response->getStatusCode(),
                        $response->getHeaders()
                    ];
                },
                function ($exception) {
                    $response = $exception->getResponse();
                    $statusCode = $response->getStatusCode();
                    throw new ApiException(
                        sprintf(
                            '[%d] Error connecting to the API (%s)',
                            $statusCode,
                            $exception->getRequest()->getUri()
                        ),
                        $statusCode,
                        $response->getHeaders(),
                        $response->getBody()
                    );
                }
            );
    }

    /**
     * Create request for operation 'pointsLatitudelongitudeHoursTimestampStarttimestampEndGet'
     *
     * @param  float $latitude A latitude value between -90° and 90°. (required)
     * @param  float $longitude A longitude value between -180° (West) and 180° (East). (required)
     * @param  \DateTime $timestamp_start A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required. (required)
     * @param  \DateTime $timestamp_end A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required. (required)
     * @param  string[] $fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* (required)
     * @param  string $unit_scale The unit scale for returned values.&lt;br&gt; (optional, default to IMPERIAL)
     *
     * @throws \InvalidArgumentException
     * @return \GuzzleHttp\Psr7\Request
     */
    protected function pointsLatitudelongitudeHoursTimestampStarttimestampEndGetRequest($latitude, $longitude, $timestamp_start, $timestamp_end, $fields, $unit_scale = 'IMPERIAL')
    {
        // verify the required parameter 'latitude' is set
        if ($latitude === null || (is_array($latitude) && count($latitude) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $latitude when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet'
            );
        }
        // verify the required parameter 'longitude' is set
        if ($longitude === null || (is_array($longitude) && count($longitude) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $longitude when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet'
            );
        }
        // verify the required parameter 'timestamp_start' is set
        if ($timestamp_start === null || (is_array($timestamp_start) && count($timestamp_start) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $timestamp_start when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet'
            );
        }
        // verify the required parameter 'timestamp_end' is set
        if ($timestamp_end === null || (is_array($timestamp_end) && count($timestamp_end) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $timestamp_end when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet'
            );
        }
        // verify the required parameter 'fields' is set
        if ($fields === null || (is_array($fields) && count($fields) === 0)) {
            throw new \InvalidArgumentException(
                'Missing the required parameter $fields when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet'
            );
        }

        $resourcePath = '/points/{latitude},{longitude}/hours/{timestampStart},{timestampEnd}';
        $formParams = [];
        $queryParams = [];
        $headerParams = [];
        $httpBody = '';
        $multipart = false;

        // query params
        if (is_array($fields)) {
            $fields = ObjectSerializer::serializeCollection($fields, 'csv', true);
        }
        if ($fields !== null) {
            $queryParams['fields'] = ObjectSerializer::toQueryValue($fields, null);
        }
        // query params
        if ($unit_scale !== null) {
            $queryParams['unitScale'] = ObjectSerializer::toQueryValue($unit_scale, null);
        }

        // path params
        if ($latitude !== null) {
            $resourcePath = str_replace(
                '{' . 'latitude' . '}',
                ObjectSerializer::toPathValue($latitude),
                $resourcePath
            );
        }
        // path params
        if ($longitude !== null) {
            $resourcePath = str_replace(
                '{' . 'longitude' . '}',
                ObjectSerializer::toPathValue($longitude),
                $resourcePath
            );
        }
        // path params
        if ($timestamp_start !== null) {
            $resourcePath = str_replace(
                '{' . 'timestampStart' . '}',
                ObjectSerializer::toPathValue($timestamp_start),
                $resourcePath
            );
        }
        // path params
        if ($timestamp_end !== null) {
            $resourcePath = str_replace(
                '{' . 'timestampEnd' . '}',
                ObjectSerializer::toPathValue($timestamp_end),
                $resourcePath
            );
        }

        // body params
        $_tempBody = null;

        if ($multipart) {
            $headers = $this->headerSelector->selectHeadersForMultipart(
                ['application/json']
            );
        } else {
            $headers = $this->headerSelector->selectHeaders(
                ['application/json'],
                []
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            // $_tempBody is the method argument, if present
            $httpBody = $_tempBody;
            // \stdClass has no __toString(), so we should encode it manually
            if ($httpBody instanceof \stdClass && $headers['Content-Type'] === 'application/json') {
                $httpBody = \GuzzleHttp\json_encode($httpBody);
            }
        } elseif (count($formParams) > 0) {
            if ($multipart) {
                $multipartContents = [];
                foreach ($formParams as $formParamName => $formParamValue) {
                    $multipartContents[] = [
                        'name' => $formParamName,
                        'contents' => $formParamValue
                    ];
                }
                // for HTTP post (form)
                $httpBody = new MultipartStream($multipartContents);

            } elseif ($headers['Content-Type'] === 'application/json') {
                $httpBody = \GuzzleHttp\json_encode($formParams);

            } else {
                // for HTTP post (form)
                $httpBody = \GuzzleHttp\Psr7\build_query($formParams);
            }
        }

        // this endpoint requires API key authentication
        $apiKey = $this->config->getApiKeyWithPrefix('X-API-KEY');
        if ($apiKey !== null) {
            $headers['X-API-KEY'] = $apiKey;
        }

        $defaultHeaders = [];
        if ($this->config->getUserAgent()) {
            $defaultHeaders['User-Agent'] = $this->config->getUserAgent();
        }

        $headers = array_merge(
            $defaultHeaders,
            $headerParams,
            $headers
        );

        $query = \GuzzleHttp\Psr7\build_query($queryParams);
        return new Request(
            'GET',
            $this->config->getHost() . $resourcePath . ($query ? "?{$query}" : ''),
            $headers,
            $httpBody
        );
    }

    /**
     * Create http client option
     *
     * @throws \RuntimeException on file opening failure
     * @return array of http client options
     */
    protected function createHttpClientOption()
    {
        $options = [];
        if ($this->config->getDebug()) {
            $options[RequestOptions::DEBUG] = fopen($this->config->getDebugFile(), 'a');
            if (!$options[RequestOptions::DEBUG]) {
                throw new \RuntimeException('Failed to open the debug file: ' . $this->config->getDebugFile());
            }
        }

        return $options;
    }
}
